@@ -29,6 +29,7 @@ from sugar import env
 from sugar.bundle.bundle import Bundle, NotInstalledException, \
     MalformedBundleException
 
+
 class ContentBundle(Bundle):
     """A Sugar content bundle
 
@@ -54,6 +55,7 @@ class ContentBundle(Bundle):
         self._library_version = None
         self._bundle_class = None
         self._activity_start = None
+        self._global_name = None
 
         info_file = self.get_file('library/library.info')
         if info_file is None:
@@ -77,8 +79,8 @@ class ContentBundle(Bundle):
             try:
                 if int(version) != 1:
                     raise MalformedBundleException(
-                        'Content bundle %s has unknown host_version number %s' %
-                        (self._path, version))
+                        'Content bundle %s has unknown host_version '
+                        'number %s' % (self._path, version))
             except ValueError:
                 raise MalformedBundleException(
                     'Content bundle %s has invalid host_version number %s' %
@@ -126,6 +128,11 @@ class ContentBundle(Bundle):
             raise MalformedBundleException(
                 'Content bundle %s does not specify a category' % self._path)
 
+        if cp.has_option(section, 'global_name'):
+            self._global_name = cp.get(section, 'global_name')
+        else:
+            self._global_name = None
+
         if cp.has_option(section, 'category_icon'):
             self._category_icon = cp.get(section, 'category_icon')
         else:
@@ -151,6 +158,11 @@ class ContentBundle(Bundle):
         else:
             self._activity_start = 'index.html'
 
+        if self._bundle_class is None and self._global_name is None:
+            raise MalformedBundleException(
+                'Content bundle %s must specify either global_name or '
+                'bundle_class' % self._path)
+
     def get_name(self):
         return self._name
 
@@ -198,14 +210,17 @@ class ContentBundle(Bundle):
     def get_start_uri(self):
         return "file://" + urllib.pathname2url(self.get_start_path())
 
-    # TODO treat ContentBundle in special way
-    # needs rethinking while fixing ContentBundle support
     def get_bundle_id(self):
-        return self._bundle_class
+        # TODO treat ContentBundle in special way
+        # needs rethinking while fixing ContentBundle support
+        if self._bundle_class is not None:
+            return self._bundle_class
+        else:
+            return self._global_name
 
-    # TODO treat ContentBundle in special way
-    # needs rethinking while fixing ContentBundle support
     def get_activity_version(self):
+        # TODO treat ContentBundle in special way
+        # needs rethinking while fixing ContentBundle support
         return self._library_version
 
     def is_installed(self):
